@@ -1,15 +1,14 @@
 
-/*
- *  $Id: expGuile.c,v 4.17 2009/01/01 16:49:26 bkorb Exp $
+/**
+ *  \file expGuile.c
  *
- *  Time-stamp:        "2007-07-04 11:19:05 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:49:26 $
+ *  Time-stamp:        "2010-07-10 16:29:48 bkorb"
  *
  *  This module implements the expression functions that should
  *  be part of Guile.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,40 +25,40 @@
  */
 
 LOCAL teGuileType
-gh_type_e( SCM typ )
+gh_type_e(SCM typ)
 {
-    if (AG_SCM_BOOL_P(   typ ))   return GH_TYPE_BOOLEAN;
-    if (AG_SCM_SYM_P(    typ ))   return GH_TYPE_SYMBOL;
-    if (AG_SCM_STRING_P( typ ))   return GH_TYPE_STRING;
-    if (AG_SCM_IS_PROC(  typ ))   return GH_TYPE_PROCEDURE;
-    if (AG_SCM_CHAR_P(   typ ))   return GH_TYPE_CHAR;
-    if (AG_SCM_VEC_P(    typ ))   return GH_TYPE_VECTOR;
-    if (AG_SCM_PAIR_P(   typ ))   return GH_TYPE_PAIR;
-    if (AG_SCM_NUM_P(    typ ))   return GH_TYPE_NUMBER;
-    if (AG_SCM_LIST_P(   typ ))   return GH_TYPE_LIST;
+    if (AG_SCM_BOOL_P(  typ)) return GH_TYPE_BOOLEAN;
+    if (AG_SCM_SYM_P(   typ)) return GH_TYPE_SYMBOL;
+    if (AG_SCM_STRING_P(typ)) return GH_TYPE_STRING;
+    if (AG_SCM_IS_PROC( typ)) return GH_TYPE_PROCEDURE;
+    if (AG_SCM_CHAR_P(  typ)) return GH_TYPE_CHAR;
+    if (AG_SCM_VEC_P(   typ)) return GH_TYPE_VECTOR;
+    if (AG_SCM_PAIR_P(  typ)) return GH_TYPE_PAIR;
+    if (AG_SCM_NUM_P(   typ)) return GH_TYPE_NUMBER;
+    if (AG_SCM_LIST_P(  typ)) return GH_TYPE_LIST;
 
     return GH_TYPE_UNDEFINED;
 }
 
 
 LOCAL SCM
-ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
+ag_scm_c_eval_string_from_file_line(tCC* pzExpr, tCC* pzFile, int line)
 {
     SCM port;
 
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-        fprintf( pfTrace, "eval from file %s line %d:\n%s\n", pzFile, line,
-                 pzExpr );
+        fprintf(pfTrace, "eval from file %s line %d:\n%s\n", pzFile, line,
+                pzExpr);
     }
 
 #if GUILE_VERSION < 106000
     {
         tSCC zEx[] = "eval-string-from-file-line";
-        SCM  expr  = scm_makfrom0str( pzExpr );
-        port = scm_mkstrport( SCM_INUM0, expr, SCM_OPN | SCM_RDNG, zEx );
+        SCM  expr  = scm_makfrom0str(pzExpr);
+        port = scm_mkstrport(SCM_INUM0, expr, SCM_OPN | SCM_RDNG, zEx);
     }
 #else
-    port = scm_open_input_string( AG_SCM_STR02SCM( pzExpr ));
+    port = scm_open_input_string(AG_SCM_STR02SCM(pzExpr));
 #endif
 
 #if GUILE_VERSION < 107000
@@ -70,11 +69,11 @@ ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
         scm_t_port* pt;
 
         if (  (pzFl == NULL)
-           || (strcmp( AG_SCM_CHARS( file ), pzFile ) != 0) )  {
+           || (strcmp(AG_SCM_CHARS(file), pzFile) != 0) )  {
             if (pzFl != NULL)
                 AGFREE(pzFl);
             AGDUPSTR(pzFl, pzFile, "eval file name");
-            file = AG_SCM_STR02SCM( pzFile );
+            file = AG_SCM_STR02SCM(pzFile);
         }
 
         pt = SCM_PTAB_ENTRY(port);
@@ -87,20 +86,20 @@ ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
         static SCM file = SCM_UNDEFINED;
         static char* pzOldFile = NULL;
 
-        if ((pzOldFile == NULL) || (strcmp( pzOldFile, pzFile ) != 0)) {
+        if ((pzOldFile == NULL) || (strcmp(pzOldFile, pzFile) != 0)) {
             if (pzOldFile != NULL)
-                AGFREE( pzOldFile );
+                AGFREE(pzOldFile);
 
-            AGDUPSTR( pzOldFile, pzFile, "scheme file source" );
-            file = scm_from_locale_string( pzFile );
+            AGDUPSTR(pzOldFile, pzFile, "scheme file source");
+            file = scm_from_locale_string(pzFile);
         }
 
-        scm_set_port_filename_x( port, file );
+        scm_set_port_filename_x(port, file);
     }
 
     {
-        SCM ln = scm_from_int( line );
-        scm_set_port_line_x( port, ln );
+        SCM ln = scm_from_int(line);
+        scm_set_port_line_x(port, ln);
     }
 #endif
 
@@ -109,10 +108,10 @@ ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
 
         /* Read expressions from that port; ignore the values.  */
         for (;;) {
-            SCM form = scm_read( port );
-            if (SCM_EOF_OBJECT_P( form ))
+            SCM form = scm_read(port);
+            if (SCM_EOF_OBJECT_P(form))
                 break;
-            ans = scm_primitive_eval_x( form );
+            ans = scm_primitive_eval_x(form);
         }
 
         return ans;
@@ -130,7 +129,7 @@ ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
  * doc:  Return the maximum value in the list
 =*/
 SCM
-ag_scm_max( SCM list )
+ag_scm_max(SCM list)
 {
     int   len;
     SCM   car;
@@ -138,17 +137,17 @@ ag_scm_max( SCM list )
 #   ifndef MAX
 #     define MAX(m,v) ((v > m) ? v : m)
 #   endif
-    len = scm_ilength( list );
+    len = scm_ilength(list);
     if (len <= 0)
         return SCM_UNDEFINED;
 
     while (--len >= 0) {
-        unsigned long val;
+        long val;
 
-        car  = SCM_CAR( list );
-        list = SCM_CDR( list );
+        car  = SCM_CAR(list);
+        list = SCM_CDR(list);
 
-        switch (gh_type_e( car )) {
+        switch (gh_type_e(car)) {
         case GH_TYPE_BOOLEAN:
             if (car == SCM_BOOL_F) {
                 val = 0;
@@ -158,25 +157,24 @@ ag_scm_max( SCM list )
             break;
 
         case GH_TYPE_CHAR:
-            val = (int)gh_scm2char( car );
+            val = (int)gh_scm2char(car);
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2ulong( car );
+            val = gh_scm2long(car);
             break;
 
         case GH_TYPE_STRING:
-            val = strtol( ag_scm2zchars( car, "number-in-string" ),
-                          NULL, 0 );
+            val = strtol(ag_scm2zchars(car, "number-in-string"), NULL, 0);
             break;
 
         default:
             continue;
         }
-        max_val = MAX( max_val, val );
+        max_val = MAX(max_val, val);
     }
 
-    return gh_long2scm( max_val );
+    return gh_long2scm(max_val);
 }
 
 
@@ -190,7 +188,7 @@ ag_scm_max( SCM list )
  * doc:  Return the minimum value in the list
 =*/
 SCM
-ag_scm_min( SCM list )
+ag_scm_min(SCM list)
 {
     int   len;
     SCM   car;
@@ -198,17 +196,17 @@ ag_scm_min( SCM list )
 #   ifndef MIN
 #     define MIN(m,v) ((v < m) ? v : m)
 #   endif
-    len = scm_ilength( list );
+    len = scm_ilength(list);
     if (len <= 0)
         return SCM_UNDEFINED;
 
     while (--len >= 0) {
-        unsigned long val;
+        long val;
 
-        car  = SCM_CAR( list );
-        list = SCM_CDR( list );
+        car  = SCM_CAR(list);
+        list = SCM_CDR(list);
 
-        switch (gh_type_e( car )) {
+        switch (gh_type_e(car)) {
         case GH_TYPE_BOOLEAN:
             if (car == SCM_BOOL_F) {
                 val = 0;
@@ -218,25 +216,24 @@ ag_scm_min( SCM list )
             break;
 
         case GH_TYPE_CHAR:
-            val = (int)gh_scm2char( car );
+            val = (int)gh_scm2char(car);
             break;
 
         case GH_TYPE_NUMBER:
-            val = gh_scm2ulong( car );
+            val = gh_scm2long(car);
             break;
 
         case GH_TYPE_STRING:
-            val = strtol( ag_scm2zchars( car, "number-in-string" ),
-                          NULL, 0 );
+            val = strtol(ag_scm2zchars(car, "number-in-string"), NULL, 0);
             break;
 
         default:
             continue;
         }
-        min_val = MIN( min_val, val );
+        min_val = MIN(min_val, val);
     }
 
-    return gh_long2scm( min_val );
+    return gh_long2scm(min_val);
 }
 
 
@@ -250,36 +247,35 @@ ag_scm_min( SCM list )
  * doc:  Compute the sum of the list of expressions.
 =*/
 SCM
-ag_scm_sum( SCM list )
+ag_scm_sum(SCM list)
 {
-    int  len = scm_ilength( list );
+    int  len = scm_ilength(list);
     long sum = 0;
 
     if (len <= 0)
-        return AG_SCM_INT2SCM( 0 );
+        return AG_SCM_INT2SCM(0);
 
     do  {
-        SCM  car = SCM_CAR( list );
-        list = SCM_CDR( list );
-        switch (gh_type_e( car )) {
+        SCM  car = SCM_CAR(list);
+        list = SCM_CDR(list);
+        switch (gh_type_e(car)) {
         default:
             return SCM_UNDEFINED;
 
         case GH_TYPE_CHAR:
-            sum += (long)(unsigned char)gh_scm2char( car );
+            sum += (long)(unsigned char)gh_scm2char(car);
             break;
 
         case GH_TYPE_NUMBER:
-            sum += gh_scm2ulong( car );
+            sum += gh_scm2long(car);
             break;
 
         case GH_TYPE_STRING:
-            sum += strtol( ag_scm2zchars( car, "number-in-string" ),
-                           NULL, 0 );
+            sum += strtol(ag_scm2zchars(car, "number-in-string"), NULL, 0);
         }
     } while (--len > 0);
 
-    return gh_long2scm( sum );
+    return gh_long2scm(sum);
 }
 
 
@@ -295,30 +291,30 @@ ag_scm_sum( SCM list )
  *       character type (i.e. non-graphic and non-white) will cause a failure.
 =*/
 SCM
-ag_scm_string_to_c_name_x( SCM str )
+ag_scm_string_to_c_name_x(SCM str)
 {
     tSCC  zFun[] = "ag_scm_string_to_c_name_x";
     tSCC  zMap[] = "cannot map unprintable chars to C name chars";
     int   len;
     char* pz;
 
-    if (! AG_SCM_STRING_P( str ))
-        scm_wrong_type_arg( zFun, 1, str );
+    if (! AG_SCM_STRING_P(str))
+        scm_wrong_type_arg(zFun, 1, str);
 
-    len = AG_SCM_STRLEN( str );
-    pz  = (char*)(void*)AG_SCM_CHARS( str );
+    len = AG_SCM_STRLEN(str);
+    pz  = (char*)(void*)AG_SCM_CHARS(str);
     while (--len >= 0) {
         char ch = *pz;
-        if (! isalnum( ch )) {
+        if (! isalnum(ch)) {
 
-            if (isspace( ch ))
+            if (isspace(ch))
                 ;
 
-            else if (isprint( ch ))
+            else if (isprint(ch))
                 *pz = '_';
 
             else
-                scm_misc_error( zFun, zMap, str );
+                scm_misc_error(zFun, zMap, str);
         }
         pz++;
     }
@@ -337,20 +333,20 @@ ag_scm_string_to_c_name_x( SCM str )
  * doc:  Change to upper case all the characters in an SCM string.
 =*/
 SCM
-ag_scm_string_upcase_x( SCM str )
+ag_scm_string_upcase_x(SCM str)
 {
     int   len;
     char* pz;
 
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    len = AG_SCM_STRLEN( str );
-    pz  = (char*)(void*)AG_SCM_CHARS( str );
+    len = AG_SCM_STRLEN(str);
+    pz  = (char*)(void*)AG_SCM_CHARS(str);
     while (--len >= 0) {
          char ch = *pz;
-        if (islower( ch ))
-            *pz = toupper( ch );
+        if (islower(ch))
+            *pz = toupper(ch);
         pz++;
     }
 
@@ -369,14 +365,14 @@ ag_scm_string_upcase_x( SCM str )
  *       only all the lower case letters are changed to upper case.
 =*/
 SCM
-ag_scm_string_upcase( SCM str )
+ag_scm_string_upcase(SCM str)
 {
     SCM res;
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
-    scm_string_upcase_x( res );
+    res = AG_SCM_STR2SCM(AG_SCM_CHARS(str), AG_SCM_STRLEN(str));
+    scm_string_upcase_x(res);
     return res;
 }
 
@@ -391,31 +387,31 @@ ag_scm_string_upcase( SCM str )
  * doc:  capitalize all the words in an SCM string.
 =*/
 SCM
-ag_scm_string_capitalize_x( SCM str )
+ag_scm_string_capitalize_x(SCM str)
 {
     int     len;
     char*   pz;
     ag_bool word_start = AG_TRUE;
 
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    len = AG_SCM_STRLEN( str );
-    pz  = (char*)(void*)AG_SCM_CHARS( str );
+    len = AG_SCM_STRLEN(str);
+    pz  = (char*)(void*)AG_SCM_CHARS(str);
 
     while (--len >= 0) {
         char ch = *pz;
 
-        if (! isalnum( ch )) {
+        if (! isalnum(ch)) {
             word_start = AG_TRUE;
 
         } else if (word_start) {
             word_start = AG_FALSE;
-            if (islower( ch ))
-                *pz = toupper( ch );
+            if (islower(ch))
+                *pz = toupper(ch);
 
-        } else if (isupper( ch ))
-            *pz = tolower( ch );
+        } else if (isupper(ch))
+            *pz = tolower(ch);
 
         pz++;
     }
@@ -436,14 +432,14 @@ ag_scm_string_capitalize_x( SCM str )
  *       other letters are made lower case.
 =*/
 SCM
-ag_scm_string_capitalize( SCM str )
+ag_scm_string_capitalize(SCM str)
 {
     SCM res;
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
-    ag_scm_string_capitalize_x( res );
+    res = AG_SCM_STR2SCM(AG_SCM_CHARS(str), AG_SCM_STRLEN(str));
+    ag_scm_string_capitalize_x(res);
     return res;
 }
 
@@ -458,20 +454,20 @@ ag_scm_string_capitalize( SCM str )
  * doc:  Change to lower case all the characters in an SCM string.
 =*/
 SCM
-ag_scm_string_downcase_x( SCM str )
+ag_scm_string_downcase_x(SCM str)
 {
     int   len;
     char* pz;
 
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    len = AG_SCM_STRLEN( str );
-    pz  = (char*)(void*)AG_SCM_CHARS( str );
+    len = AG_SCM_STRLEN(str);
+    pz  = (char*)(void*)AG_SCM_CHARS(str);
     while (--len >= 0) {
         char ch = *pz;
-        if (isupper( ch ))
-            *pz = tolower( ch );
+        if (isupper(ch))
+            *pz = tolower(ch);
         pz++;
     }
 
@@ -490,16 +486,71 @@ ag_scm_string_downcase_x( SCM str )
  *       only all the upper case letters are changed to lower case.
 =*/
 SCM
-ag_scm_string_downcase( SCM str )
+ag_scm_string_downcase(SCM str)
 {
     SCM res;
-    if (! AG_SCM_STRING_P( str ))
+    if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
-    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
-    ag_scm_string_downcase_x( res );
+    res = AG_SCM_STR2SCM(AG_SCM_CHARS(str), AG_SCM_STRLEN(str));
+    ag_scm_string_downcase_x(res);
     return res;
 }
+
+
+/*=gfunc string_to_camelcase
+ *
+ * what:   make a string be CamelCase
+ * general_use:
+ *
+ * exparg: str , input/output string
+ *
+ * doc:  Capitalize the first letter of each block of letters and numbers,
+ *       and stripping out characters that are not alphanumerics.
+ *       For example, "alpha-beta0gamma" becomes "AlphaBeta0gamma".
+=*/
+SCM
+ag_scm_string_to_camelcase(SCM str)
+{
+    int   len;
+    char* pzd, * res;
+    char* pzs;
+    ag_bool cap_done = AG_FALSE;
+
+    if (! AG_SCM_STRING_P(str))
+        return SCM_UNDEFINED;
+
+    len = AG_SCM_STRLEN(str);
+    res = pzd = ag_scribble(len + 1);
+    pzs = (char*)(void*)AG_SCM_CHARS(str);
+
+    while (--len >= 0) {
+        unsigned int ch = *(pzs++);
+        if (islower(ch)) {
+            if (! cap_done) {
+                ch = toupper(ch);
+                cap_done = AG_TRUE;
+            }
+
+        } else if (isupper(ch)) {
+            if (cap_done)
+                ch = tolower(ch);
+            else
+                cap_done = AG_TRUE;
+
+        } else if (isdigit(ch)) {
+            cap_done = AG_FALSE;
+
+        } else {
+            cap_done = AG_FALSE;
+            continue;
+        }
+
+        *(pzd++) = ch;
+    }
+
+    return AG_SCM_STR2SCM(res, (pzd - res));
+}
 /*
  * Local Variables:
  * mode: C
