@@ -1,10 +1,10 @@
 
-/*
- *  $Id: e4a1cf8e4df5e26182320150930e21a516f990a5 $
- *
- *  Time-stamp:        "2010-02-24 08:42:12 bkorb"
+/**
+ * \file funcCase.c
  *
  *  This module implements the CASE text function.
+ *
+ *  Time-stamp:        "2010-07-16 17:25:03 bkorb"
  */
 /*=--subblock=exparg=arg_name,arg_desc,arg_optional,arg_list=*/
 
@@ -41,7 +41,7 @@
 
 tSCC zBadRe[]  = "Invalid regular expression:  error %d (%s):\n%s";
 
-typedef tSuccess (tSelectProc)( tCC* pzText, tCC* pzMatch );
+typedef tSuccess (tSelectProc)(char const * sample, char const * pattern);
 static tSelectProc
     Select_Compare,
     Select_Compare_End,
@@ -83,52 +83,52 @@ static void
 upString(char* pz);
 
 static tSuccess
-Select_Compare( tCC* pzText, tCC* pzMatch );
+Select_Compare(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Compare_End( tCC* pzText, tCC* pzMatch );
+Select_Compare_End(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Compare_Start( tCC* pzText, tCC* pzMatch );
+Select_Compare_Start(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Compare_Full( tCC* pzText, tCC* pzMatch );
+Select_Compare_Full(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Equivalent( tCC* pzText, tCC* pzMatch );
+Select_Equivalent(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Equivalent_End( tCC* pzText, tCC* pzMatch );
+Select_Equivalent_End(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Equivalent_Start( tCC* pzText, tCC* pzMatch );
+Select_Equivalent_Start(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Equivalent_Full( tCC* pzText, tCC* pzMatch );
+Select_Equivalent_Full(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match( tCC* pzText, tCC* pzMatch );
+Select_Match(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_End( tCC* pzText, tCC* pzMatch );
+Select_Match_End(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_Start( tCC* pzText, tCC* pzMatch );
+Select_Match_Start(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_Full( tCC* pzText, tCC* pzMatch );
+Select_Match_Full(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_Always( tCC* pzText, tCC* pzMatch );
+Select_Match_Always(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_Existence( tCC* pzText, tCC* pzMatch );
+Select_Match_Existence(char const * sample, char const * pattern);
 
 static tSuccess
-Select_Match_NonExistence( tCC* pzText, tCC* pzMatch );
+Select_Match_NonExistence(char const * sample, char const * pattern);
 
 static tMacro*
-mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan );
+mLoad_Select(tTemplate * pT, tMacro* pMac, char const ** ppzScan);
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -140,9 +140,9 @@ compile_re(regex_t* pRe, char const * pzPat, int flags)
     int  rerr = regcomp(pRe, pat, flags);
     if (rerr != 0) {
         char zEr[ SCRIBBLE_SIZE ];
-        regerror( rerr, pRe, zEr, sizeof( zEr ));
-        fprintf( stderr, zBadRe, rerr, zEr, pzPat );
-        AG_ABEND( "Bad regular expression" );
+        regerror(rerr, pRe, zEr, sizeof(zEr));
+        fprintf(stderr, zBadRe, rerr, zEr, pzPat);
+        AG_ABEND("Bad regular expression");
     }
 }
 
@@ -169,18 +169,18 @@ upString(char* pz)
  *       will find an address.
 =*/
 static tSuccess
-Select_Compare( tCC* pzText, tCC* pzMatch )
+Select_Compare(char const * sample, char const * pattern)
 {
-    return (strstr( pzText, pzMatch )) ? SUCCESS : FAILURE;
+    return (strstr(sample, pattern)) ? SUCCESS : FAILURE;
 }
 
 SCM
-ag_scm_string_contains_p( SCM text, SCM substr )
+ag_scm_string_contains_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
 
-    return (strstr( pzText, pzSubstr) == NULL) ? SCM_BOOL_F : SCM_BOOL_T;
+    return (strstr(pzText, pzSubstr) == NULL) ? SCM_BOOL_F : SCM_BOOL_T;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -198,15 +198,15 @@ ag_scm_string_contains_p( SCM text, SCM substr )
  *       strcmp(3) returns zero for comparing the string ends.
 =*/
 static tSuccess
-Select_Compare_End( tCC* pzText, tCC* pzMatch )
+Select_Compare_End(char const * sample, char const * pattern)
 {
-    size_t   vlen = strlen( pzMatch );
-    size_t   tlen = strlen( pzText );
+    size_t   vlen = strlen(pattern);
+    size_t   tlen = strlen(sample);
     tSuccess res;
 
     if (tlen < vlen)
         res = FAILURE;
-    else if (strcmp( pzText + (tlen - vlen), pzMatch ) == 0)
+    else if (strcmp(sample + (tlen - vlen), pattern) == 0)
          res = SUCCESS;
     else res = FAILURE;
 
@@ -214,11 +214,11 @@ Select_Compare_End( tCC* pzText, tCC* pzMatch )
 }
 
 SCM
-ag_scm_string_ends_with_p( SCM text, SCM substr )
+ag_scm_string_ends_with_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
-    return (SUCCESSFUL( Select_Compare_End( pzText, pzSubstr )))
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    return (SUCCESSFUL(Select_Compare_End(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
@@ -237,12 +237,12 @@ ag_scm_string_ends_with_p( SCM text, SCM substr )
  * doc:  Test to see if a string starts with a substring.
 =*/
 static tSuccess
-Select_Compare_Start( tCC* pzText, tCC* pzMatch )
+Select_Compare_Start(char const * sample, char const * pattern)
 {
-    size_t  vlen = strlen( pzMatch );
+    size_t  vlen = strlen(pattern);
     tSuccess res;
 
-    if (strncmp( pzText, pzMatch, vlen ) == 0)
+    if (strncmp(sample, pattern, vlen) == 0)
          res = SUCCESS;
     else res = FAILURE;
 
@@ -250,11 +250,11 @@ Select_Compare_Start( tCC* pzText, tCC* pzMatch )
 }
 
 SCM
-ag_scm_string_starts_with_p( SCM text, SCM substr )
+ag_scm_string_starts_with_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
-    return (SUCCESSFUL( Select_Compare_Start( pzText, pzSubstr )))
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    return (SUCCESSFUL(Select_Compare_Start(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
@@ -273,18 +273,18 @@ ag_scm_string_starts_with_p( SCM text, SCM substr )
  * doc:  Test to see if two strings exactly match.
 =*/
 static tSuccess
-Select_Compare_Full( tCC* pzText, tCC* pzMatch )
+Select_Compare_Full(char const * sample, char const * pattern)
 {
-    return (strcmp( pzText, pzMatch ) == 0) ? SUCCESS : FAILURE;
+    return (strcmp(sample, pattern) == 0) ? SUCCESS : FAILURE;
 }
 
 SCM
-ag_scm_string_equals_p( SCM text, SCM substr )
+ag_scm_string_equals_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
 
-    return (strcmp( pzText, pzSubstr) == 0) ? SCM_BOOL_T : SCM_BOOL_F;
+    return (strcmp(pzText, pzSubstr) == 0) ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -305,34 +305,34 @@ ag_scm_string_equals_p( SCM text, SCM substr )
  *       Viz., '-', '_' and '^' are equivalent.
 =*/
 static tSuccess
-Select_Equivalent( tCC* pzText, tCC* pzMatch )
+Select_Equivalent(char const * sample, char const * pattern)
 {
     char*    pz;
     tSuccess res = SUCCESS;
-    AGDUPSTR( pz, pzText, "equiv chars" );
-    upString( pz );
-    if (strstr( pz, pzMatch ) == NULL)
+    AGDUPSTR(pz, sample, "equiv chars");
+    upString(pz);
+    if (strstr(pz, pattern) == NULL)
         res = FAILURE;
-    AGFREE( (void*)pz );
+    AGFREE((void*)pz);
 
     return res;
 }
 
 SCM
-ag_scm_string_contains_eqv_p( SCM text, SCM substr )
+ag_scm_string_contains_eqv_p(SCM text, SCM substr)
 {
     tSCC zSrch[] = "search string";
     char* pzSubstr;
     SCM   res;
 
-    AGDUPSTR( pzSubstr, ag_scm2zchars( substr, zSrch ), "substring" );
+    AGDUPSTR(pzSubstr, ag_scm2zchars( substr, zSrch ), "substring");
 
-    upString( pzSubstr );
-    if (SUCCESSFUL( Select_Equivalent( ag_scm2zchars( text, "sample text" ),
-                                       pzSubstr )))
+    upString(pzSubstr);
+    if (SUCCESSFUL(Select_Equivalent(ag_scm2zchars(text, "sample text"),
+                                     pzSubstr)))
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
-    AGFREE( (void*)pzSubstr );
+    AGFREE((void*)pzSubstr);
     return res;
 }
 
@@ -351,25 +351,25 @@ ag_scm_string_contains_eqv_p( SCM text, SCM substr )
  * doc:  Test to see if a string ends with an equivalent string.
 =*/
 static tSuccess
-Select_Equivalent_End( tCC* pzText, tCC* pzMatch )
+Select_Equivalent_End(char const * sample, char const * pattern)
 {
-    size_t   vlen = strlen( pzMatch );
-    size_t   tlen = strlen( pzText );
+    size_t   vlen = strlen(pattern);
+    size_t   tlen = strlen(sample);
 
     if (tlen < vlen)
         return FAILURE;
 
-    return (streqvcmp( pzText + (tlen - vlen), pzMatch ) == 0)
+    return (streqvcmp(sample + (tlen - vlen), pattern) == 0)
            ? SUCCESS
            : FAILURE;
 }
 
 SCM
-ag_scm_string_ends_eqv_p( SCM text, SCM substr )
+ag_scm_string_ends_eqv_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
-    return (SUCCESSFUL( Select_Equivalent_End( pzText, pzSubstr )))
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    return (SUCCESSFUL(Select_Equivalent_End( pzText, pzSubstr )))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
@@ -388,21 +388,21 @@ ag_scm_string_ends_eqv_p( SCM text, SCM substr )
  * doc:  Test to see if a string starts with an equivalent string.
 =*/
 static tSuccess
-Select_Equivalent_Start( tCC* pzText, tCC* pzMatch )
+Select_Equivalent_Start(char const * sample, char const * pattern)
 {
-    size_t   vlen = strlen( pzMatch );
+    size_t   vlen = strlen(pattern);
 
-    return (strneqvcmp( pzText, pzMatch, (int)vlen ) == 0)
+    return (strneqvcmp(sample, pattern, (int)vlen) == 0)
            ? SUCCESS
            : FAILURE;
 }
 
 SCM
-ag_scm_string_starts_eqv_p( SCM text, SCM substr )
+ag_scm_string_starts_eqv_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
-    return (SUCCESSFUL( Select_Equivalent_Start( pzText, pzSubstr )))
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    return (SUCCESSFUL(Select_Equivalent_Start(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
@@ -428,13 +428,13 @@ ag_scm_string_starts_eqv_p( SCM text, SCM substr )
  *       strings, then the query is passed through to @code{scm_num_eq_p()}.
 =*/
 static tSuccess
-Select_Equivalent_Full( tCC* pzText, tCC* pzMatch )
+Select_Equivalent_Full(char const * sample, char const * pattern)
 {
-    return (streqvcmp( pzText, pzMatch ) == 0) ? SUCCESS : FAILURE;
+    return (streqvcmp(sample, pattern) == 0) ? SUCCESS : FAILURE;
 }
 
 SCM
-ag_scm_string_eqv_p( SCM text, SCM substr )
+ag_scm_string_eqv_p(SCM text, SCM substr)
 {
     char* pzText;
     char* pzSubstr;
@@ -443,13 +443,13 @@ ag_scm_string_eqv_p( SCM text, SCM substr )
      *  We are overloading the "=" operator.  Our arguments may be
      *  numbers...
      */
-    if (! AG_SCM_STRING_P( text ) || ! AG_SCM_STRING_P( substr ))
-        return scm_num_eq_p( text, substr );
+    if (! AG_SCM_STRING_P(text) || ! AG_SCM_STRING_P(substr))
+        return scm_num_eq_p(text, substr);
 
-    pzText   = ag_scm2zchars( text, "text to match" );
-    pzSubstr = ag_scm2zchars( substr, "match expr" );
+    pzText   = ag_scm2zchars(text, "text to match");
+    pzSubstr = ag_scm2zchars(substr, "match expr");
 
-    return (streqvcmp( pzText, pzSubstr) == 0) ? SCM_BOOL_T : SCM_BOOL_F;
+    return (streqvcmp(pzText, pzSubstr) == 0) ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -481,55 +481,55 @@ ag_scm_string_eqv_p( SCM text, SCM substr )
  *       Case is not significant.
 =*/
 static tSuccess
-Select_Match( tCC* pzText, tCC* pzMatch )
+Select_Match(char const * sample, char const * pattern)
 {
     /*
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
-        void *    mat = (void *)pzMatch;
-        regex_t*  pRe = AGALOC(sizeof( *pRe ), "select match re");
+        void *    mat = (void *)pattern;
+        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match re");
         compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)0,
+    if (regexec((regex_t*)pCurMacro->funcPrivate, sample, (size_t)0,
                  NULL, 0) != 0)
         return FAILURE;
     return SUCCESS;
 }
 
 SCM
-ag_scm_string_has_match_p( SCM text, SCM substr )
+ag_scm_string_has_match_p(SCM text, SCM substr)
 {
     SCM      res;
     regex_t  re;
 
-    compile_re( &re, ag_scm2zchars( substr, "match expr" ), REG_EXTENDED );
+    compile_re(&re, ag_scm2zchars( substr, "match expr" ), REG_EXTENDED);
 
-    if (regexec(&re, ag_scm2zchars( text, "text to match" ), (size_t)0,
+    if (regexec(&re, ag_scm2zchars(text, "text to match"), (size_t)0,
                  NULL, 0) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
 
 SCM
-ag_scm_string_has_eqv_match_p( SCM text, SCM substr )
+ag_scm_string_has_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM      res;
     regex_t  re;
 
-    compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
+    compile_re(&re, pzSubstr, REG_EXTENDED | REG_ICASE);
 
     if (regexec(&re, pzText, (size_t)0, NULL, 0) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
@@ -563,66 +563,67 @@ ag_scm_string_has_eqv_match_p( SCM text, SCM substr )
  *       Case is not significant.
 =*/
 static tSuccess
-Select_Match_End( tCC* pzText, tCC* pzMatch )
+Select_Match_End(char const * sample, char const * pattern)
 {
     regmatch_t m[2];
     /*
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
-        void *    mat = (void *)pzMatch;
-        regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match end re" );
+        void *    mat = (void *)pattern;
+        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match end re");
         compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, sample, (size_t)2, m, 0)
+        != 0)
         return FAILURE;
-    if (m[0].rm_eo != strlen( pzText ))
+    if (m[0].rm_eo != strlen(sample))
         return FAILURE;
     return SUCCESS;
 }
 
 SCM
-ag_scm_string_end_match_p( SCM text, SCM substr )
+ag_scm_string_end_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED );
+    compile_re(&re, pzSubstr, REG_EXTENDED);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
-    else if (m[0].rm_eo != strlen( pzText ))
+    else if (m[0].rm_eo != strlen(pzText))
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
 
 SCM
-ag_scm_string_end_eqv_match_p( SCM text, SCM substr )
+ag_scm_string_end_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
+    compile_re(&re, pzSubstr, REG_EXTENDED | REG_ICASE);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
-    else if (m[0].rm_eo != strlen( pzText ))
+    else if (m[0].rm_eo != strlen(pzText))
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
@@ -656,20 +657,21 @@ ag_scm_string_end_eqv_match_p( SCM text, SCM substr )
  *       Case is not significant.
 =*/
 static tSuccess
-Select_Match_Start( tCC* pzText, tCC* pzMatch )
+Select_Match_Start(char const * sample, char const * pattern)
 {
     regmatch_t m[2];
     /*
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
-        void *    mat = (void *)pzMatch;
-        regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match start re" );
+        void *    mat = (void *)pattern;
+        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match start re");
         compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, sample, (size_t)2, m, 0)
+        != 0)
         return FAILURE;
     if (m[0].rm_so != 0)
         return FAILURE;
@@ -677,15 +679,15 @@ Select_Match_Start( tCC* pzText, tCC* pzMatch )
 }
 
 SCM
-ag_scm_string_start_match_p( SCM text, SCM substr )
+ag_scm_string_start_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED );
+    compile_re(&re, pzSubstr, REG_EXTENDED);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
@@ -693,21 +695,21 @@ ag_scm_string_start_match_p( SCM text, SCM substr )
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
 
 SCM
-ag_scm_string_start_eqv_match_p( SCM text, SCM substr )
+ag_scm_string_start_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
+    compile_re(&re, pzSubstr, REG_EXTENDED | REG_ICASE);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
@@ -715,7 +717,7 @@ ag_scm_string_start_eqv_match_p( SCM text, SCM substr )
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
@@ -750,7 +752,7 @@ ag_scm_string_start_eqv_match_p( SCM text, SCM substr )
  *       must be expressed in your regular expression.
 =*/
 static tSuccess
-Select_Match_Full( tCC* pzText, tCC* pzMatch )
+Select_Match_Full(char const * sample, char const * pattern)
 {
     regmatch_t m[2];
 
@@ -758,98 +760,104 @@ Select_Match_Full( tCC* pzText, tCC* pzMatch )
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
-        void *    mat = (void *)pzMatch;
-        regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match full re" );
+        void *    mat = (void *)pattern;
+        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match full re");
 
         if (OPT_VALUE_TRACE > TRACE_EXPRESSIONS) {
-            fprintf( pfTrace, "Compiling ``%s'' with bits 0x%lX\n",
-                     pzMatch, pCurMacro->res );
+            fprintf(pfTrace, "Compiling ``%s'' with bits 0x%lX\n",
+                     pattern, pCurMacro->res);
         }
         compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = pRe;
     }
 
-    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, sample, (size_t)2, m, 0)
+        != 0)
         return FAILURE;
 
-    if (  (m[0].rm_eo != strlen( pzText ))
-       || (m[0].rm_so != 0) )
+    if (  (m[0].rm_eo != strlen( sample ))
+       || (m[0].rm_so != 0))
         return FAILURE;
     return SUCCESS;
 }
 
 SCM
-ag_scm_string_match_p( SCM text, SCM substr )
+ag_scm_string_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED );
+    compile_re(&re, pzSubstr, REG_EXTENDED);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
-    else if (  (m[0].rm_eo != strlen( pzText ))
+    else if (  (m[0].rm_eo != strlen(pzText))
             || (m[0].rm_so != 0) )
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
 
 SCM
-ag_scm_string_eqv_match_p( SCM text, SCM substr )
+ag_scm_string_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars( text, "text to match" );
-    char* pzSubstr = ag_scm2zchars( substr, "match expr" );
+    char* pzText   = ag_scm2zchars(text, "text to match");
+    char* pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
 
-    compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
+    compile_re(&re, pzSubstr, REG_EXTENDED | REG_ICASE);
 
     if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
-    else if (  (m[0].rm_eo != strlen( pzText ))
+    else if (  (m[0].rm_eo != strlen(pzText))
             || (m[0].rm_so != 0) )
          res = SCM_BOOL_F;
     else res = SCM_BOOL_T;
 
-    regfree( &re );
+    regfree(&re);
 
     return res;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
+/**
  *  We don't bother making a Guile function for any of these :)
  */
 static tSuccess
-Select_Match_Always( tCC* pzText, tCC* pzMatch )
+Select_Match_Always(char const * sample, char const * pattern)
 {
     return SUCCESS;
 }
 
-/*
- *  If the "pzText" addresses "zNil", then we couldn't find a value
- *  and defaulted to an empty string.  So, the result exists if
- *  the pzText address is anything except "zNil".
+/**
+ *  If the "sample" addresses "zNil", then we couldn't find a value and
+ *  defaulted to an empty string.  So, the result is true if the sample
+ *  address is anything except "zNil".
  */
 static tSuccess
-Select_Match_Existence( tCC* pzText, tCC* pzMatch )
+Select_Match_Existence(char const * sample, char const * pattern)
 {
-    return (pzText != zNil) ? SUCCESS : FAILURE;
+    return (sample != zNil) ? SUCCESS : FAILURE;
 }
 
+/**
+ *  If the "sample" addresses "zUndefined", then we couldn't find a value and
+ *  defaulted to an empty string.  So, the result false if the sample address
+ *  is anything except "zUndefined".
+ */
 static tSuccess
-Select_Match_NonExistence( tCC* pzText, tCC* pzMatch )
+Select_Match_NonExistence(char const * sample, char const * pattern)
 {
-    return (pzText == zNil) ? SUCCESS : FAILURE;
+    return (sample == zNil) ? SUCCESS : FAILURE;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -931,15 +939,15 @@ Select_Match_NonExistence( tCC* pzText, tCC* pzMatch )
  *    For a complete description, @xref{CASE}.
 =*/
 tMacro*
-mFunc_Case( tTemplate* pT, tMacro* pMac )
+mFunc_Case(tTemplate* pT, tMacro* pMac)
 {
-    typedef tSuccess (t_match_proc)( tCC*, tCC* );
+    typedef tSuccess (t_match_proc)(char const *, char const *);
     /*
      *  There are only 15 procedures because the case insenstive matching
      *  get mapped into the previous four.  The last three are "match always",
      *  "match if a value was found" "match if no value found".
      */
-    static t_match_proc* match_procs[] = {
+    static t_match_proc * const match_procs[] = {
         &Select_Compare_Full,
         &Select_Compare_End,
         &Select_Compare_Start,
@@ -960,7 +968,7 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
         &Select_Match_NonExistence
     };
 
-    tSCC* apzMatchName[] = {
+    static char const * const match_names[] = {
         "COMPARE_FULL",
         "COMPARE_END",
         "COMPARE_START",
@@ -983,7 +991,7 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
 
     tMacro*   pEnd = pT->aMacros + pMac->endIndex;
     ag_bool needFree;
-    tCC* pzSampleText = evalExpression( &needFree );
+    char const * pzSampleText = evalExpression(&needFree);
 
     /*
      *  Search through the selection clauses until we either
@@ -994,12 +1002,12 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
         pMac = pT->aMacros + pMac->sibIndex;
         if (pMac >= pEnd) {
             if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS) {
-                fprintf( pfTrace, "CASE string `%s' did not match\n",
-                         pzSampleText );
+                fprintf(pfTrace, "CASE string `%s' did not match\n",
+                        pzSampleText);
 
                 if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
-                    fprintf( pfTrace, zFileLine, pCurTemplate->pzTplFile,
-                             pMac->lineNo );
+                    fprintf(pfTrace, zFileLine, pCurTemplate->pzTplFile,
+                            pMac->lineNo);
             }
 
             break;
@@ -1009,37 +1017,37 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
          *  The current macro becomes the selected selection macro
          */
         pCurMacro = pMac;
-        mRes = (*(match_procs[ pMac->funcCode & 0x0F ])
-               )( pzSampleText, pT->pzTemplText + pMac->ozText );
+        mRes = (*(match_procs[pMac->funcCode & 0x0F])
+               )(pzSampleText, pT->pzTemplText + pMac->ozText);
 
         /*
          *  IF match, THEN generate and stop looking for a match.
          */
-        if (SUCCEEDED( mRes )) {
+        if (SUCCEEDED(mRes)) {
             if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS) {
-                fprintf( pfTrace, "CASE string `%s' %s matched `%s'\n",
-                         pzSampleText,
-                         apzMatchName[ pMac->funcCode & 0x0F ],
-                         pT->pzTemplText + pMac->ozText );
+                fprintf(pfTrace, "CASE string `%s' %s matched `%s'\n",
+                        pzSampleText,
+                        match_names[pMac->funcCode & 0x0F],
+                        pT->pzTemplText + pMac->ozText);
 
                 if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
-                    fprintf( pfTrace, zFileLine, pCurTemplate->pzTplFile,
-                             pMac->lineNo );
+                    fprintf(pfTrace, zFileLine, pCurTemplate->pzTplFile,
+                            pMac->lineNo);
             }
 
-            generateBlock( pT, pMac + 1, pT->aMacros + pMac->sibIndex );
+            generateBlock(pT, pMac + 1, pT->aMacros + pMac->sibIndex);
             break;
         }
         else if (OPT_VALUE_TRACE == TRACE_EVERYTHING) {
-            fprintf( pfTrace, "CASE no match: `%s' %s vs. `%s'\n",
-                     pzSampleText,
-                     apzMatchName[ pMac->funcCode & 0x0F ],
-                     pT->pzTemplText + pMac->ozText );
+            fprintf(pfTrace, "CASE no match: `%s' %s vs. `%s'\n",
+                    pzSampleText,
+                    match_names[pMac->funcCode & 0x0F],
+                    pT->pzTemplText + pMac->ozText);
         }
     }
 
     if (needFree)
-        AGFREE( (void*)pzSampleText );
+        AGFREE((void*)pzSampleText);
 
     return pEnd;
 }
@@ -1051,7 +1059,7 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
  *  when the template is first read in (before processing).
  */
 tMacro*
-mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Case(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
     size_t         srcLen     = (size_t)pMac->res;   /* macro len  */
     tCaseStack     save_stack = current_case;
@@ -1067,12 +1075,12 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  THEN woops!  what are we to case on?
      */
     if (srcLen == 0)
-        AG_ABEND_IN( pT, pMac, "expressionless CASE" );
+        AG_ABEND_IN(pT, pMac, "expressionless CASE");
 
     /*
      *  Load the expression
      */
-    (void)mLoad_Expr( pT, pMac, ppzScan );
+    (void)mLoad_Expr(pT, pMac, ppzScan);
 
     /*
      *  IF this is the first time here,
@@ -1090,7 +1098,7 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         for (i=0; i < FUNC_CT; i++)
             apSelectOnly[i] = &mLoad_Bogus;
 
-        memcpy( (void*)apCaseLoad, apLoadProc, sizeof( apLoadProc ));
+        memcpy((void*)apCaseLoad, apLoadProc, sizeof( apLoadProc ));
         apSelectOnly[ FTYP_COMMENT] = mLoad_Comment;
         apSelectOnly[ FTYP_SELECT ] = \
         apCaseLoad[   FTYP_SELECT ] = &mLoad_Select;
@@ -1112,9 +1120,9 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     /*
      *  Continue parsing the template from this nested level
      */
-    pEsacMac = parseTemplate( pMac+1, ppzScan );
+    pEsacMac = parseTemplate(pMac+1, ppzScan);
     if (*ppzScan == NULL)
-        AG_ABEND_IN( pT, pMac, "ESAC not found" );
+        AG_ABEND_IN(pT, pMac, "ESAC not found");
 
     /*
      *  Tell the last select macro where its end is.
@@ -1160,11 +1168,11 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *    the @code{CASE} macro description.
 =*/
 static tMacro*
-mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
+mLoad_Select(tTemplate * pT, tMacro* pMac, char const ** ppzScan)
 {
-    char const*    pzScan = *ppzScan;  /* text after macro */
+    char const *    pzScan = *ppzScan;  /* text after macro */
     char*          pzCopy = pT->pNext; /* next text dest   */
-    char const*    pzSrc  = (char*)pMac->ozText; /* macro text */
+    char const *    pzSrc  = (char*)pMac->ozText; /* macro text */
     long           srcLen = pMac->res;           /* macro len  */
 
     tSCC zInvSel[] = "Invalid selection clause";
@@ -1176,7 +1184,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     papLoadProc = apCaseLoad;
     pMac->res   = 0;
     if (srcLen == 0)
-        AG_ABEND_IN( pT, pMac, "Empty macro text" );
+        AG_ABEND_IN(pT, pMac, "Empty macro text");
 
     /*
      *  IF the first character is an asterisk,
@@ -1184,7 +1192,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      */
     if (*pzSrc == '*') {
         pzSrc++;
-        if (isspace( *pzSrc ) || (*pzSrc == NUL)) {
+        if (isspace(*pzSrc) || (*pzSrc == NUL)) {
             typ    = (int)FTYP_SELECT_MATCH_ANYTHING;
             srcLen = 0;
             pMac->ozText = 0;
@@ -1229,7 +1237,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         default:
             goto bad_sel;
         }
-        if ((pzSrc[1] != NUL) && (! isspace( pzSrc[1] )))
+        if ((pzSrc[1] != NUL) && (! isspace(pzSrc[1])))
             goto bad_sel;
 
         typ = (int)((pzSrc[-1] == '!')
@@ -1240,7 +1248,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 
     default:
     bad_sel:
-        AG_ABEND_IN( pT, pMac, zInvSel );
+        AG_ABEND_IN(pT, pMac, zInvSel);
     }
 
     /*
@@ -1253,19 +1261,19 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         typ |= (int)FTYP_SELECT_COMPARE_SKP_END;
     }
 
-    if (! isspace( *pzSrc ))
-        AG_ABEND_IN( pT, pMac, zInvSel );
+    if (! isspace(*pzSrc))
+        AG_ABEND_IN(pT, pMac, zInvSel);
 
     while (isspace(*pzSrc)) pzSrc++;
-    srcLen -= pzSrc - (char const*)pMac->ozText;
+    srcLen -= pzSrc - (char const *)pMac->ozText;
     if (srcLen <= 0)
-        AG_ABEND_IN( pT, pMac, zInvSel );
+        AG_ABEND_IN(pT, pMac, zInvSel);
 
     /*
      *  See if we are doing case insensitive regular expressions
      */
-    if (   (typ & (int)FTYP_SELECT_EQV_MATCH_FULL)
-        == (int)FTYP_SELECT_EQV_MATCH_FULL) {
+    if (  (typ & (int)FTYP_SELECT_EQV_MATCH_FULL)
+       == (int)FTYP_SELECT_EQV_MATCH_FULL) {
         int  bitSet;
         pMac->res = REG_EXTENDED | REG_ICASE;
 
@@ -1285,7 +1293,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pMac->ozText = (pzCopy - pT->pzTemplText);
     if (typ == (int)FTYP_SELECT_EQUIVALENT) {
         do  {
-            *(pzCopy++) = toupper( *(pzSrc++) );
+            *(pzCopy++) = toupper(*(pzSrc++));
         } while (--srcLen > 0);
     } else {
         do  {
@@ -1311,11 +1319,11 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 
 void
-mUnload_Select( tMacro* pMac )
+mUnload_Select(tMacro* pMac)
 {
     if (pMac->funcPrivate != NULL) {
         regex_t* pRe = (regex_t*)pMac->funcPrivate;
-        regfree( pRe );
+        regfree(pRe);
         AGFREE(pRe);
     }
 }
