@@ -1,14 +1,13 @@
-/*
- *  $Id: 6d52e6abaefa9e965f3e09dcf94c4efd98f4b44a $
+/**
+ * \file gdinit.c
  *
  *  getdefs Copyright (c) 1999-2010 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Time-stamp:        "2010-02-24 08:38:31 bkorb"
- *            by: bkorb
+ *  Time-stamp:        "2010-08-04 20:50:01 bkorb"
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -24,7 +23,7 @@
  *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
+static char const zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
 /* = = = START-STATIC-FORWARD = = = */
 static char*
